package com.example.businesscard

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Email
import androidx.compose.material.icons.filled.Phone
import androidx.compose.material.icons.filled.Share
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.businesscard.ui.theme.BusinessCardTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            BusinessCardTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ) {
                    BusinessCard()
                }
            }
        }
    }
}

@Composable
fun BusinessCard() {
    Surface(
        color = Color(7, 48, 66)
    ) {
        Column {
            MainSection(
                modifier = Modifier
                    .fillMaxWidth()
                    .weight(1f)
            )

            ContactsSection(
                modifier = Modifier
                    .fillMaxWidth()
            )
        }
    }
}

@Composable
fun MainSection(modifier: Modifier = Modifier) {
    Column(
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = modifier
    ) {
        val imagePainter = painterResource(R.drawable.android_logo)
        Image(
            painter = imagePainter,
            contentDescription = null,
            modifier = Modifier.width(80.dp)
        )

        Text(
            text = stringResource(R.string.name),
            fontSize = 56.sp,
            fontWeight = FontWeight.Light,
            color = Color.White
        )

        Text(
            text = stringResource(R.string.title),
            color = Color(61, 220, 132)
        )
    }
}

@Composable
fun ContactsSection(modifier: Modifier = Modifier) {
    Column(
        modifier = modifier.padding(bottom = 40.dp)
    ) {
        ContactItem(
            icon = Icons.Filled.Phone,
            description = stringResource(R.string.phone_description),
            value = stringResource(R.string.phone_value)
        )

        ContactItem(
            icon = Icons.Filled.Share,
            description = stringResource(R.string.social_description),
            value = stringResource(R.string.social_value)
        )

        ContactItem(
            icon = Icons.Filled.Email,
            description = stringResource(R.string.mail_description),
            value = stringResource(R.string.mail_value)
        )
    }
}

@Composable
fun ContactItem(icon: ImageVector, description: String, value: String) {
    Divider(
        color = Color.White
    )
    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = Modifier.padding(horizontal = 40.dp)
    ) {
        Icon(
            icon,
            contentDescription = description,
            tint = Color(61, 220, 132),
            modifier = Modifier.padding(8.dp)
        )
        Text(
            text = value,
            color = Color.White,
            modifier = Modifier.padding(8.dp)
        )
    }
}

@Preview(showBackground = true)
@Composable
fun DefaultPreview() {
    BusinessCardTheme {
        BusinessCard()
    }
}