package com.example.composearticle

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Surface
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.composearticle.ui.theme.ComposeArticleTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            ComposeArticleTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    color = MaterialTheme.colors.background
                ) {
                    Article()
                    TaskManager()
                    Quadrant()
                }
            }
        }
    }
}

@Composable
fun Article(modifier: Modifier = Modifier) {
    Column(modifier = modifier.fillMaxSize()) {
        Image(
            painter = painterResource(R.drawable.bg_compose_background),
            contentDescription = null,
            contentScale = ContentScale.FillWidth
        )

        Text(
            text = stringResource(R.string.title_text),
            fontSize = 24.sp,
            modifier = modifier.padding(16.dp)
        )

        Text(
            text = stringResource(R.string.first_paragraph),
            modifier = modifier.padding(horizontal = 15.dp),
            textAlign = TextAlign.Justify
        )

        Text(
            text = stringResource(R.string.second_paragraph),
            modifier = modifier.padding(16.dp),
            textAlign = TextAlign.Justify
        )
    }
}

@Composable
fun TaskManager(modifier: Modifier = Modifier) {
    Column(
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = modifier.fillMaxSize()
    ) {
        Image(
            painter = painterResource(R.drawable.ic_task_completed),
            contentDescription = null
        )

        Text(
            text = stringResource(R.string.tasks_title),
            fontWeight = FontWeight.Bold,
            modifier = modifier.padding(top = 24.dp, bottom = 8.dp)
        )

        Text(
            text = stringResource(R.string.tasks_subtitle),
            fontSize = 16.sp
        )
    }
}

@Composable
fun Quadrant(modifier: Modifier = Modifier) {
    Column {
        Row(
            modifier = modifier
                .weight(weight = 0.5f)
        ) {
            Card(
                title = stringResource(R.string.lt_title),
                text = stringResource(R.string.lt_text),
                color = Color.Green,
                modifier = Modifier.weight(weight = 0.5f)
            )

            Card(
                title = stringResource(R.string.rt_title),
                text = stringResource(R.string.rt_text),
                color = Color.Yellow,
                modifier = Modifier.weight(weight = 0.5f)
            )
        }

        Row(
            modifier = modifier
                .weight(weight = 0.5f)
        ) {
            Card(
                title = stringResource(R.string.lb_title),
                text = stringResource(R.string.lb_text),
                color = Color.Cyan,
                modifier = Modifier.weight(weight = 0.5f)
            )

            Card(
                title = stringResource(R.string.rb_title),
                text = stringResource(R.string.rb_text),
                color = Color.LightGray,
                modifier = Modifier.weight(weight = 0.5f)
            )
        }
    }
}

@Composable
fun Card(
    title: String,
    text: String,
    color: Color,
    modifier: Modifier = Modifier
) {
    Column(
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = modifier
            .background(color)
            .padding(16.dp)
            .fillMaxSize()
    ) {
        Text(
            text = title,
            fontWeight = FontWeight.Bold,
            modifier = Modifier.padding(bottom = 16.dp)
        )

        Text(
            text = text,
            textAlign = TextAlign.Justify
        )
    }
}

@Preview(showBackground = true)
@Composable
fun ArticlePreview() {
    ComposeArticleTheme {
        Article()
    }
}

@Preview(showBackground = true)
@Composable
fun TaskManagerPreview() {
    ComposeArticleTheme {
        TaskManager()
    }
}

@Preview(showBackground = true)
@Composable
fun QuadrantPreview() {
    ComposeArticleTheme {
        Quadrant()
    }
}